@@ -20,7 +20,7 @@ use Module::Install::Base;
               &get_bzip2_version
             );
 
-$VERSION = sprintf "%d.%02d%02d", q/0.30.4/ =~ /(\d+)/g;
+$VERSION = sprintf "%d.%02d%02d", q/0.30.8/ =~ /(\d+)/g;
 
 # ---------------------------------------------------------------------------
 
@@ -201,7 +201,7 @@ sub _prompt_user_for_program_locations
 
     my $choice = $self->prompt(
       "Where can I find your \"$program_name\" executable?" .
-      "$allowed_types" => $full_path);
+      "$allowed_types", $full_path);
 
     $program_info{$program_name} =
       { path => undef, type => undef, version => undef }, next
@@ -361,7 +361,6 @@ sub _Make_Absolute
 
 sub get_gnu_version
 {
-  my $self = shift;
   my $program = shift;
 
   die "Missing GNU program to get version for" unless defined $program;
@@ -370,14 +369,14 @@ sub get_gnu_version
 
   # Newer versions
   {
-    my $command = "$program --version 2>" . File::Spec->devnull();
+    my $command = "\"$program\" --version 2>" . File::Spec->devnull();
     $version_message = `$command`;
   }
 
   # Older versions use -V
   unless($version_message =~ /\b(GNU|Free\s+Software\s+Foundation)\b/s)
   {
-    my $command = "$program -V 2>&1 1>" . File::Spec->devnull();
+    my $command = "\"$program\" -V 2>&1 1>" . File::Spec->devnull();
     $version_message = `$command`;
   }
 
@@ -393,10 +392,9 @@ sub get_gnu_version
 
 sub get_bzip2_version
 {
-  my $self = shift;
   my $program = shift;
 
-  my $command = "$program --help 2>&1 1>" . File::Spec->devnull();
+  my $command = "\"$program\" --help 2>&1 1>" . File::Spec->devnull();
   my $version_message = `$command`;
 
   my ($program_version) = $version_message =~ /^.*?([\d]+\.[\d.a-z]+)/s;
@@ -408,4 +406,4 @@ sub get_bzip2_version
 
 # ---------------------------------------------------------------------------
 
-#line 632
+#line 629
